@@ -5,7 +5,7 @@
  * Written by Weyfour WWWWolf (Urpo Lankinen),
  * 2001-01-11 and onward
  *
- * $Id: infopipe_ui.c,v 1.1 2001/01/10 23:45:53 wwwwolf Exp $
+ * $Id: infopipe_ui.c,v 1.4 2002/03/06 13:23:56 wwwwolf Exp $
  *
  ***********************************************************/
 
@@ -17,6 +17,7 @@
 #include <xmms/plugin.h>
 #include <xmms/util.h>
 
+#include "../config.h"
 #include "infopipe.h"
 
 /*
@@ -29,11 +30,11 @@ void show_about(void) {
   strcat(stuff, "Descriptive fun for the trivia-crazed and\n");
   strcat(stuff, "exhibitionists alike!\n\n");
   strcat(stuff, "Version ");
-  strcat(stuff, INFOPIPE_VERSION);
-  strcat(stuff, "\nby Weyfour WWWWolf / Urpo Lankinen\n");
+  strcat(stuff, VERSION);
+  strcat(stuff, "\nby Weyfour WWWWolf (aka Urpo Lankinen)\n");
   strcat(stuff, "\n<wwwwolf@iki.fi>\n");
   strcat(stuff, "http://www.iki.fi/wwwwolf/\n");
-  strcat(stuff, "\nSee CREDITS for more information.\n");
+  strcat(stuff, "\nSee README for more information.\n");
 
 
   xmms_show_message("About InfoPipe",
